@@ -47,6 +47,7 @@
 #include "gok-spy.h"
 #include "gok-data.h"
 
+
 static GdkFilterReturn
 gok_xkb_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer data)
 {
@@ -73,18 +74,17 @@ void
 on_window1_realize                     (GtkWidget       *widget,
                                         gpointer         user_data)
 {
-  gboolean is_dock = (gboolean) user_data;
+  struct gok_window_realize_data *window_realize_data = (struct gok_window_realize_data *) user_data;
   GdkKeymap *map = gdk_keymap_get_default ();
 
   gok_main_center_corepointer (widget);
 
-  if (is_dock) {
+  if (window_realize_data->is_dock) {
 	  gok_main_set_wm_dock (TRUE);
   }
   else {
 	  if (widget->window) {
-		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | 
-					      GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
+		  gdk_window_set_decorations (widget->window, GDK_DECOR_ALL | GDK_DECOR_MINIMIZE | GDK_DECOR_MAXIMIZE);
 		  gdk_window_set_functions (widget->window, GDK_FUNC_MOVE | GDK_FUNC_RESIZE);
 	  }
   }
@@ -93,15 +93,15 @@ on_window1_realize                     (GtkWidget       *widget,
 
   if (!gok_keyboard_xkb_select (GDK_WINDOW_XDISPLAY (widget->window)))
 	  g_warning ("Could not register for XKB events!");
+  
+  if (window_realize_data->use_libusb == FALSE) {
+  	gok_input_init (gok_input_extension_filter);
+  }
 
-  gok_input_init (gok_input_extension_filter);
+  gdk_window_add_filter (NULL, gok_xkb_filter, NULL);
+  g_signal_connect (map, "keys-changed", (GCallback) gok_spy_keymap_listener, NULL);
 
-  gdk_window_add_filter (NULL,
-			 gok_xkb_filter,
-			 NULL);
-
-  g_signal_connect (map, "keys-changed",
-		    (GCallback) gok_spy_keymap_listener, NULL);
+  g_free(window_realize_data);
 }
 
 
