@@ -911,16 +911,14 @@ gboolean gok_action_revert (GokAction* pAction)
 			{
 				/* no, free the name and copy the backup name to the name */
 				g_free (pAction->pName);
-				pAction->pName = g_malloc (strlen (pAction->pNameBackup) + 1);
-				strcpy (pAction->pName, pAction->pNameBackup);
+				pAction->pName = g_strdup (pAction->pNameBackup);
 
 				bSettingsChanged = TRUE;
 			}
 		}
 		else /* name is NULL */
 		{
-			pAction->pName = g_malloc (strlen (pAction->pNameBackup) + 1);
-			strcpy (pAction->pName, pAction->pNameBackup);
+			pAction->pName = g_strdup (pAction->pNameBackup);
 
 			bSettingsChanged = TRUE;
 		}
@@ -937,16 +935,14 @@ gboolean gok_action_revert (GokAction* pAction)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pAction->pDisplayName);
-				pAction->pDisplayName = g_malloc (strlen (pAction->pDisplayNameBackup) + 1);
-				strcpy (pAction->pDisplayName, pAction->pDisplayNameBackup);
+				pAction->pDisplayName = g_strdup (pAction->pDisplayNameBackup);
 
 				bSettingsChanged = TRUE;
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pAction->pDisplayName = g_malloc (strlen (pAction->pDisplayNameBackup) + 1);
-			strcpy (pAction->pDisplayName, pAction->pDisplayNameBackup);
+			pAction->pDisplayName = g_strdup (pAction->pDisplayNameBackup);
 
 			bSettingsChanged = TRUE;
 		}
@@ -1007,14 +1003,12 @@ void gok_action_backup (GokAction* pAction)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pAction->pNameBackup);
-				pAction->pNameBackup = g_malloc (strlen (pAction->pName) + 1);
-				strcpy (pAction->pNameBackup, pAction->pName);
+				pAction->pNameBackup = g_strdup (pAction->pName);
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pAction->pNameBackup = g_malloc (strlen (pAction->pName) + 1);
-			strcpy (pAction->pNameBackup, pAction->pName);
+			pAction->pNameBackup = g_strdup (pAction->pName);
 		}
 	}
 	
@@ -1036,14 +1030,12 @@ void gok_action_backup (GokAction* pAction)
 			{
 				/* no, free the backup name and copy the name to backup */
 				g_free (pAction->pDisplayNameBackup);
-				pAction->pDisplayNameBackup = g_malloc (strlen (pAction->pDisplayName) + 1);
-				strcpy (pAction->pDisplayNameBackup, pAction->pDisplayName);
+				pAction->pDisplayNameBackup = g_strdup (pAction->pDisplayName);
 			}
 		}
 		else /* backup name is NULL */
 		{
-			pAction->pDisplayNameBackup = g_malloc (strlen (pAction->pDisplayName) + 1);
-			strcpy (pAction->pDisplayNameBackup, pAction->pDisplayName);
+			pAction->pDisplayNameBackup = g_strdup (pAction->pDisplayName);
 		}
 	}
 
