@@ -227,7 +227,7 @@ gok_key_label_from_keysym_string (const gchar *str)
 	gchar *cp;
 	size_t strl;
 
-	if (!str) return g_strdup ("<nil>");
+	if (!str) return g_strdup (_("<nil>"));
 	strl = strlen(str);
 
 	if (!strcmp (str, "KP_Divide")) {
@@ -254,16 +254,16 @@ gok_key_label_from_keysym_string (const gchar *str)
 	else if (!strcmp (str, "KP_End")) {
 		cp = _("End");
 	}
-	else if (!strcmp (str, "KP_Up")) {
+	else if (!strcmp (str, "KP_Up") || !strcmp (str, "Up")) {
 		cp = _("Up");
 	}
-	else if (!strcmp (str, "KP_Down")) {
+	else if (!strcmp (str, "KP_Down") || !strcmp (str, "Down")) {
 		cp = _("Down");
 	}
-	else if (!strcmp (str, "KP_Left")) {
+	else if (!strcmp (str, "KP_Left") || !strcmp (str, "Left")) {
 		cp = _("Left");
 	}
-	else if (!strcmp (str, "KP_Right")) {
+	else if (!strcmp (str, "KP_Right") || !strcmp (str, "Right")) {
 		cp = _("Right");
 	}
 	else if (!strcmp (str, "KP_Begin")) {
@@ -290,12 +290,8 @@ gok_key_label_from_keysym_string (const gchar *str)
 	else if (!strcmp (str, "Mode_switch")) {
 		cp = _("Mode\nswitch");
 	}
-/*      REMOVE COMMENTS POST-BRANCH: freeze applies currently */
  	else if (!strcmp (str, "Hiragana_Katakana")) {
-	        cp = "Hiragana\nKatakana";
-/*
 	        cp = _("Hiragana\nKatakana");
- */
 	}
 	else if (strncmp(str, "KP_", 3) == 0) {
  	        cp = g_strdup (str + 3);
@@ -1120,8 +1116,7 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 		gok_modifier_add ((char *)g_strdup ((const char *)pStringAttributeValue));
 		
 		/* store the name of the modifier on the key */
-		pKey->ModifierName = (gchar*)g_malloc (strlen ((char *)pStringAttributeValue) + 1);
-		strcpy (pKey->ModifierName, (char *)pStringAttributeValue);
+		pKey->ModifierName = g_strdup ((char *)pStringAttributeValue);
 
 		/* what type of modifier is this? */
 		pStringSubAttributeValue = xmlGetProp (pNode, (const xmlChar *) "modifiertype");
@@ -1359,8 +1354,7 @@ gboolean gok_key_add_label (GokKey* pKey, gchar* pLabelText, guint level, guint
 			if ((pKeyLabel->level == level) && (pKeyLabel->group == group))
 			{
 				g_free (pKeyLabel->Text);
-				pKeyLabel->Text = (gchar*)g_malloc (strlen(pLabelText) + 1);
-				strcpy (pKeyLabel->Text, pLabelText);
+				pKeyLabel->Text = g_strdup (pLabelText);
 				
 				break;
 			}
@@ -1772,134 +1766,134 @@ void gok_key_add_output (GokKey* pKey, gint Type, gchar* pName, AccessibleKeySyn
 **/
 void gok_key_set_button_name (GokKey* pKey)
 {
-	gchar styleButton[200];
-	gchar styleText[200];
+	const gchar *styleButton;
+	const gchar *styleText;
 	
 	switch (pKey->Style)
 	{
 	case KEYSTYLE_DOCK:
 	case KEYSTYLE_NORMAL:
-		strcpy (styleButton, "StyleButtonNormal");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonNormal";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_BRANCH: 
-		strcpy (styleButton, "StyleButtonBranch");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranch";
+		styleText = "StyleTextNormal";
 		break;
 	case KEYSTYLE_BRANCHMODAL:
-		strcpy (styleButton, "StyleButtonBranch");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranch";
+		styleText = "StyleTextNormal";
 		break;
 	case KEYSTYLE_BRANCHBACK: 			
 		/* disable the button if we can't branch back */
 		if (gok_branchbackstack_is_empty() == TRUE)
 		{
-			strcpy (styleButton, "StyleButtonDisabled");
-			strcpy (styleText, "StyleTextDisabled");
+			styleButton = "StyleButtonDisabled";
+			styleText = "StyleTextDisabled";
 		}
 		else
 		{
-			strcpy (styleButton, "StyleButtonBranchBack");
-			strcpy (styleText, "StyleTextNormal");
+			styleButton = "StyleButtonBranchBack";
+			styleText = "StyleTextNormal";
 		}
 		break;
 
 	case KEYSTYLE_GENERALDYNAMIC:
-		strcpy (styleButton, "StyleButtonGeneralDynamic");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonGeneralDynamic";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_SELECT:
-		strcpy (styleButton, "StyleButtonSelect");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonSelect";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_BRANCHMENUS:
-		strcpy (styleButton, "StyleButtonBranchMenus");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchMenus";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_BRANCHMENUITEMS:
-		strcpy (styleButton, "StyleButtonBranchMenuItems");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchMenuItems";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_MENUITEM:
-		strcpy (styleButton, "StyleButtonMenuItem");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonMenuItem";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_BRANCHTOOLBARS:
-		strcpy (styleButton, "StyleButtonBranchToolbars");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchToolbars";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_ABOUT: 
 	case KEYSTYLE_BRANCHGUI:
-		strcpy (styleButton, "StyleButtonBranchGUI");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchGUI";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_PAGESELECTION:
-		strcpy (styleButton, "StyleButtonBranchPageSelection");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchPageSelection";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_BRANCHGUIACTIONS:
 	case KEYSTYLE_EDIT:
 	case KEYSTYLE_REPEATNEXT:
-		strcpy (styleButton, "StyleButtonBranchGuiActions");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonBranchGuiActions";
+		styleText = "StyleTextNormal";
 		break;
 		
 	case KEYSTYLE_HYPERLINK:
-		strcpy (styleButton, "StyleButtonHyperlink");
-		strcpy (styleText, "StyleTextHyperlink");
+		styleButton = "StyleButtonHyperlink";
+		styleText = "StyleTextHyperlink";
 		break;
 
 	case KEYSTYLE_BRANCHHYPERTEXT:
-		strcpy (styleButton, "StyleButtonHyperText");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonHyperText";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_HTMLACTION:
-		strcpy (styleButton, "StyleButtonHtmlAction");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonHtmlAction";
+		styleText = "StyleTextNormal";
 		break;
 
 	case KEYSTYLE_BRANCHALPHABET:
 	case KEYSTYLE_BRANCHTEXT:
-		strcpy (styleButton, "StyleButtonBranchAlphabet");
-		strcpy (styleText, "StyleTextBranchAlphabet");
+		styleButton = "StyleButtonBranchAlphabet";
+		styleText = "StyleTextBranchAlphabet";
 		break;
 		
 	case KEYSTYLE_SETTINGS:
-		strcpy (styleButton, "StyleButtonSettings");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonSettings";
+		styleText = "StyleTextNormal";
 		break;
 					
 	case KEYSTYLE_ADDWORD:
 	case KEYSTYLE_HELP:
-		strcpy (styleButton, "StyleButtonHelp");
-		strcpy (styleText, "StyleTextHelp");
+		styleButton = "StyleButtonHelp";
+		styleText = "StyleTextHelp";
 		break;
 					
 	case KEYSTYLE_POINTERCONTROL:
 	case KEYSTYLE_WORDCOMPLETE:
 	case KEYSTYLE_SPELL:
-		strcpy (styleButton, "StyleButtonWordComplete");
-		strcpy (styleText, "StyleTextWordComplete");
+		styleButton = "StyleButtonWordComplete";
+		styleText = "StyleTextWordComplete";
 		break;
 		
 	case KEYSTYLE_INSENSITIVE:		
-		strcpy (styleButton, "StyleButtonDisabled");
-		strcpy (styleText, "StyleTextDisabled");
+		styleButton = "StyleButtonDisabled";
+		styleText = "StyleTextDisabled";
 		break;
 	default:
 		gok_log_x ("Warning: default hit in gok_key_set_button_name! Key = %s\n", gok_key_get_label (pKey));
-		strcpy (styleButton, "StyleButtonNormal");
-		strcpy (styleText, "StyleTextNormal");
+		styleButton = "StyleButtonNormal";
+		styleText = "StyleTextNormal";
 		break;
 	}
 	
@@ -2405,8 +2399,7 @@ gok_keyimage_new (GokKey* pKey, gchar* pFilename)
 	
 	if (pFilename != NULL)
 	{
-		pNewImage->Filename = (gchar*) g_malloc (strlen (pFilename) + 1);
-		strcpy (pNewImage->Filename, pFilename);
+		pNewImage->Filename = g_strdup (pFilename);
 	}
 	
 	if (pKey != NULL)
