@@ -566,6 +566,8 @@ gok_main_open(gint argc, gchar *argv[])
 {
 	GnomeProgram *gok_program;
 	GOptionContext *context;
+	gboolean create_dirs = TRUE;
+	int i;
 
 	/* initialize member data */
 	m_pForegroundWindowAccessible = NULL;
@@ -580,6 +582,18 @@ gok_main_open(gint argc, gchar *argv[])
 	context	= g_option_context_new (_("The GNOME On-screen Keyboard"));
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
+	/*
+	 * Preprocess the arguments to see if --login was included.  Need to
+	 * do this before calling gnome_program_init (which normally processes
+	 * the arguments) since this affects how we call gnome_program_init.
+	 */
+	for (i = 0; i < argc; i++) {
+		if (strcmp (argv[i], "--login") == 0) {
+			create_dirs = FALSE;
+			break;
+		}
+	}
+
 	/* Initialize Gnome */
 	gok_program = gnome_program_init (PACKAGE, VERSION,
 		LIBGNOMEUI_MODULE, argc, argv,
@@ -587,6 +601,7 @@ gok_main_open(gint argc, gchar *argv[])
 		GNOME_PROGRAM_STANDARD_PROPERTIES,
 	        GNOME_PARAM_APP_DATADIR, DATADIR"/gok", 
 		LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
+		GNOME_PARAM_CREATE_DIRECTORIES, create_dirs,
 		NULL);
 		
 	if (!bonobo_init (&argc, argv))
@@ -1216,7 +1231,7 @@ static gboolean gok_main_xevie_io (GIOChannel *source,
 				   gpointer data)
 {
     XEvent xevie_event;
-
+#ifdef HAVE_XEVIE
     while (xevie_dpy && XPending (xevie_dpy)) {
       XMotionEvent *motion_event;
       gboolean has_active_key = gok_scanner_key_is_active ();
@@ -1234,6 +1249,7 @@ static gboolean gok_main_xevie_io (GIOChannel *source,
       if (!has_active_key)
 	XevieSendEvent (xevie_dpy, &xevie_event, XEVIE_UNMODIFIED);
     }
+#endif
     return TRUE;
 }
 
@@ -1826,7 +1842,6 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 				"can_focus", FALSE,
 				"type", GTK_WINDOW_TOPLEVEL,
 				"window-position", GTK_WIN_POS_CENTER,
-				"title","GOK",
 				"allow_grow", TRUE,
 				"allow_shrink", TRUE,
 				"border_width", 0,
@@ -1836,6 +1851,9 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 			     "signal::destroy", on_window1_destroy, NULL,
 			     NULL);
 
+	g_set_application_name (_("GOK"));
+	gtk_window_set_default_icon_name ("gok");
+
 	m_OurResizeWidth = 200;
 	m_OurResizeHeight = 100;
 	gtk_window_set_default_size (GTK_WINDOW (window1), m_OurResizeWidth, m_OurResizeHeight);
